.. image:: https://img.shields.io/travis/lsst-sqre/zenodio.svg

#########################
zenodio — I/O with Zenodo
#########################

Python library for uploading research artifacts to Zenodo_ with their REST API and downloading artifacts from community collections with their OAI-PMH Datacite v3 harvest API.

*In development.*

License
=======

Copyright 2015 AURA/LSST

MIT license.

.. _Zenodo: http://zenodo.org
